# Automatic-Youtube-Maker
**Descrição breve:** Gerador de video de 1 minuto automatico, utilizando ComfyUI, narration-xtts2, story-children-video-maker e story-chilren-gemma3 .

## Índice

- [Introdução](#introdução)
- [Instalação](#instalação)
  - [Pré-requisitos](#pré-requisitos)
  - [Configuração de path_history](#configuração-de-path_history)
  - [Instalando Dependências](#instalando-dependências)

## Introdução

[Em construlçai]

## Instalação

### Instale Automatic-Youtube-Maker


```shell
pip install Automatic-Youtube-Maker

```

### Configuração de path_history

Pelo menos uma vez é necessário implementar a função **install_packeges.start()** para definir o caminho.


```python
import automatic_youtube_maker as automatic

automatic.install_packeges.start()

```
### Pré-requisitos


- Python = "3.8+"

